@@ -75,6 +75,9 @@ module SimpleCaptcha #:nodoc
         params << "-pointsize 22"
         params << "-implode #{ImageHelpers.implode}"
         params << "label:#{text}"
+        unless SimpleCaptcha.font.empty?
+          params << "-font #{SimpleCaptcha.font}"
+        end
         if SimpleCaptcha.noise and SimpleCaptcha.noise > 0
           params << "-evaluate Uniform-noise #{SimpleCaptcha.noise}"
         end
